# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class ConversionTracker(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'all_conversion_value': 'str',
        'all_conversions': 'int',
        'app_conversion': 'ConversionTrackerServiceAppConversion',
        'app_link_conversion': 'ConversionTrackerServiceAppLinkConversion',
        'category': 'ConversionTrackerServiceCategory',
        'conversion_counting_type': 'ConversionTrackerServiceConversionCountingType',
        'conversion_tracker_id': 'int',
        'conversion_tracker_track_id': 'int',
        'conversion_tracker_name': 'str',
        'conversion_tracker_type': 'ConversionTrackerServiceConversionTrackerType',
        'conversion_value': 'str',
        'conversions': 'int',
        'exclude_from_bidding': 'ConversionTrackerServiceExcludeFromBidding',
        'measurement_period': 'int',
        'most_recent_conversion_date': 'str',
        'status': 'ConversionTrackerServiceStatus',
        'user_revenue_value': 'str',
        'web_conversion': 'ConversionTrackerServiceWebConversion'
    }

    attribute_map = {
        'account_id': 'accountId',
        'all_conversion_value': 'allConversionValue',
        'all_conversions': 'allConversions',
        'app_conversion': 'appConversion',
        'app_link_conversion': 'appLinkConversion',
        'category': 'category',
        'conversion_counting_type': 'conversionCountingType',
        'conversion_tracker_id': 'conversionTrackerId',
        'conversion_tracker_track_id': 'conversionTrackerTrackId',
        'conversion_tracker_name': 'conversionTrackerName',
        'conversion_tracker_type': 'conversionTrackerType',
        'conversion_value': 'conversionValue',
        'conversions': 'conversions',
        'exclude_from_bidding': 'excludeFromBidding',
        'measurement_period': 'measurementPeriod',
        'most_recent_conversion_date': 'mostRecentConversionDate',
        'status': 'status',
        'user_revenue_value': 'userRevenueValue',
        'web_conversion': 'webConversion'
    }

    def __init__(self, account_id=None, all_conversion_value=None, all_conversions=None, app_conversion=None, app_link_conversion=None, category=None, conversion_counting_type=None, conversion_tracker_id=None, conversion_tracker_track_id=None, conversion_tracker_name=None, conversion_tracker_type=None, conversion_value=None, conversions=None, exclude_from_bidding=None, measurement_period=None, most_recent_conversion_date=None, status=None, user_revenue_value=None, web_conversion=None, local_vars_configuration=None):  # noqa: E501
        """ConversionTracker - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._all_conversion_value = None
        self._all_conversions = None
        self._app_conversion = None
        self._app_link_conversion = None
        self._category = None
        self._conversion_counting_type = None
        self._conversion_tracker_id = None
        self._conversion_tracker_track_id = None
        self._conversion_tracker_name = None
        self._conversion_tracker_type = None
        self._conversion_value = None
        self._conversions = None
        self._exclude_from_bidding = None
        self._measurement_period = None
        self._most_recent_conversion_date = None
        self._status = None
        self._user_revenue_value = None
        self._web_conversion = None
        self.discriminator = None

        self.account_id = account_id
        self.all_conversion_value = all_conversion_value
        self.all_conversions = all_conversions
        self.app_conversion = app_conversion
        self.app_link_conversion = app_link_conversion
        self.category = category
        self.conversion_counting_type = conversion_counting_type
        self.conversion_tracker_id = conversion_tracker_id
        self.conversion_tracker_track_id = conversion_tracker_track_id
        self.conversion_tracker_name = conversion_tracker_name
        self.conversion_tracker_type = conversion_tracker_type
        self.conversion_value = conversion_value
        self.conversions = conversions
        self.exclude_from_bidding = exclude_from_bidding
        self.measurement_period = measurement_period
        self.most_recent_conversion_date = most_recent_conversion_date
        self.status = status
        self.user_revenue_value = user_revenue_value
        self.web_conversion = web_conversion

    @property
    def account_id(self):
        """Gets the account_id of this ConversionTracker.  # noqa: E501

        <div lang=\"ja\">アカウントIDです。</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :return: The account_id of this ConversionTracker.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this ConversionTracker.

        <div lang=\"ja\">アカウントIDです。</div> <div lang=\"en\">Account ID.</div>   # noqa: E501

        :param account_id: The account_id of this ConversionTracker.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def all_conversion_value(self):
        """Gets the all_conversion_value of this ConversionTracker.  # noqa: E501

        <div lang=\"ja\"> 自動入札設定対象のコンバージョン値と、対象外のコンバージョン値の合計です。<br> この値はGETでのみ取得可能です。ADD、SET時のレスポンスではnullで返却されます。 </div> <div lang=\"en\"> Total value of conversions to be included to auto bidding and to be exluded from auto bidding.<br> This value can be obtained by GET operation only. ADD and SET responses will return null. </div>   # noqa: E501

        :return: The all_conversion_value of this ConversionTracker.  # noqa: E501
        :rtype: str
        """
        return self._all_conversion_value

    @all_conversion_value.setter
    def all_conversion_value(self, all_conversion_value):
        """Sets the all_conversion_value of this ConversionTracker.

        <div lang=\"ja\"> 自動入札設定対象のコンバージョン値と、対象外のコンバージョン値の合計です。<br> この値はGETでのみ取得可能です。ADD、SET時のレスポンスではnullで返却されます。 </div> <div lang=\"en\"> Total value of conversions to be included to auto bidding and to be exluded from auto bidding.<br> This value can be obtained by GET operation only. ADD and SET responses will return null. </div>   # noqa: E501

        :param all_conversion_value: The all_conversion_value of this ConversionTracker.  # noqa: E501
        :type: str
        """

        self._all_conversion_value = all_conversion_value

    @property
    def all_conversions(self):
        """Gets the all_conversions of this ConversionTracker.  # noqa: E501

        <div lang=\"ja\"> 自動入札設定対象のコンバージョン数と、対象外のコンバージョン数の合計です。<br> この値はGETでのみ取得可能です。ADD、SET時のレスポンスではnullで返却されます。 </div> <div lang=\"en\"> Total number of conversions to be included to auto bidding and to be excluded from auto bidding.<br> This value can be obtained by GET operation only. ADD and SET responses will return null. </div>   # noqa: E501

        :return: The all_conversions of this ConversionTracker.  # noqa: E501
        :rtype: int
        """
        return self._all_conversions

    @all_conversions.setter
    def all_conversions(self, all_conversions):
        """Sets the all_conversions of this ConversionTracker.

        <div lang=\"ja\"> 自動入札設定対象のコンバージョン数と、対象外のコンバージョン数の合計です。<br> この値はGETでのみ取得可能です。ADD、SET時のレスポンスではnullで返却されます。 </div> <div lang=\"en\"> Total number of conversions to be included to auto bidding and to be excluded from auto bidding.<br> This value can be obtained by GET operation only. ADD and SET responses will return null. </div>   # noqa: E501

        :param all_conversions: The all_conversions of this ConversionTracker.  # noqa: E501
        :type: int
        """

        self._all_conversions = all_conversions

    @property
    def app_conversion(self):
        """Gets the app_conversion of this ConversionTracker.  # noqa: E501


        :return: The app_conversion of this ConversionTracker.  # noqa: E501
        :rtype: ConversionTrackerServiceAppConversion
        """
        return self._app_conversion

    @app_conversion.setter
    def app_conversion(self, app_conversion):
        """Sets the app_conversion of this ConversionTracker.


        :param app_conversion: The app_conversion of this ConversionTracker.  # noqa: E501
        :type: ConversionTrackerServiceAppConversion
        """

        self._app_conversion = app_conversion

    @property
    def app_link_conversion(self):
        """Gets the app_link_conversion of this ConversionTracker.  # noqa: E501


        :return: The app_link_conversion of this ConversionTracker.  # noqa: E501
        :rtype: ConversionTrackerServiceAppLinkConversion
        """
        return self._app_link_conversion

    @app_link_conversion.setter
    def app_link_conversion(self, app_link_conversion):
        """Sets the app_link_conversion of this ConversionTracker.


        :param app_link_conversion: The app_link_conversion of this ConversionTracker.  # noqa: E501
        :type: ConversionTrackerServiceAppLinkConversion
        """

        self._app_link_conversion = app_link_conversion

    @property
    def category(self):
        """Gets the category of this ConversionTracker.  # noqa: E501


        :return: The category of this ConversionTracker.  # noqa: E501
        :rtype: ConversionTrackerServiceCategory
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this ConversionTracker.


        :param category: The category of this ConversionTracker.  # noqa: E501
        :type: ConversionTrackerServiceCategory
        """

        self._category = category

    @property
    def conversion_counting_type(self):
        """Gets the conversion_counting_type of this ConversionTracker.  # noqa: E501


        :return: The conversion_counting_type of this ConversionTracker.  # noqa: E501
        :rtype: ConversionTrackerServiceConversionCountingType
        """
        return self._conversion_counting_type

    @conversion_counting_type.setter
    def conversion_counting_type(self, conversion_counting_type):
        """Sets the conversion_counting_type of this ConversionTracker.


        :param conversion_counting_type: The conversion_counting_type of this ConversionTracker.  # noqa: E501
        :type: ConversionTrackerServiceConversionCountingType
        """

        self._conversion_counting_type = conversion_counting_type

    @property
    def conversion_tracker_id(self):
        """Gets the conversion_tracker_id of this ConversionTracker.  # noqa: E501

        <div lang=\"ja\">コンバージョントラッカーのIDです。<br> このフィールドは、SET時に必須となります。</div> <div lang=\"en\">ConversionTracker ID.<br> This field is required in SET operation.</div>   # noqa: E501

        :return: The conversion_tracker_id of this ConversionTracker.  # noqa: E501
        :rtype: int
        """
        return self._conversion_tracker_id

    @conversion_tracker_id.setter
    def conversion_tracker_id(self, conversion_tracker_id):
        """Sets the conversion_tracker_id of this ConversionTracker.

        <div lang=\"ja\">コンバージョントラッカーのIDです。<br> このフィールドは、SET時に必須となります。</div> <div lang=\"en\">ConversionTracker ID.<br> This field is required in SET operation.</div>   # noqa: E501

        :param conversion_tracker_id: The conversion_tracker_id of this ConversionTracker.  # noqa: E501
        :type: int
        """

        self._conversion_tracker_id = conversion_tracker_id

    @property
    def conversion_tracker_track_id(self):
        """Gets the conversion_tracker_track_id of this ConversionTracker.  # noqa: E501

        <div lang=\"ja\">トラッキング用コンバージョントラッカーIDです。<br> ADD時、このフィールドは省略可能となります。※conversionTrackerTypeがAPP_LINK_CONVERSIONの場合は必須です。</div> <div lang=\"en\">ConversionTracker ID for tracking.<br> This field is optional in ADD operation. *If conversionTrackerType is APP_LINK_CONVERSION, this field is required.</div>   # noqa: E501

        :return: The conversion_tracker_track_id of this ConversionTracker.  # noqa: E501
        :rtype: int
        """
        return self._conversion_tracker_track_id

    @conversion_tracker_track_id.setter
    def conversion_tracker_track_id(self, conversion_tracker_track_id):
        """Sets the conversion_tracker_track_id of this ConversionTracker.

        <div lang=\"ja\">トラッキング用コンバージョントラッカーIDです。<br> ADD時、このフィールドは省略可能となります。※conversionTrackerTypeがAPP_LINK_CONVERSIONの場合は必須です。</div> <div lang=\"en\">ConversionTracker ID for tracking.<br> This field is optional in ADD operation. *If conversionTrackerType is APP_LINK_CONVERSION, this field is required.</div>   # noqa: E501

        :param conversion_tracker_track_id: The conversion_tracker_track_id of this ConversionTracker.  # noqa: E501
        :type: int
        """

        self._conversion_tracker_track_id = conversion_tracker_track_id

    @property
    def conversion_tracker_name(self):
        """Gets the conversion_tracker_name of this ConversionTracker.  # noqa: E501

        <div lang=\"ja\">コンバージョントラッカーの名称です。<br> このフィールドは、ADD時に必須となり、SET時に省略可能となります。</div> <div lang=\"en\">Conversion tracker name.<br> This field is required in ADD operation, and is optional in SET operation.</div>   # noqa: E501

        :return: The conversion_tracker_name of this ConversionTracker.  # noqa: E501
        :rtype: str
        """
        return self._conversion_tracker_name

    @conversion_tracker_name.setter
    def conversion_tracker_name(self, conversion_tracker_name):
        """Sets the conversion_tracker_name of this ConversionTracker.

        <div lang=\"ja\">コンバージョントラッカーの名称です。<br> このフィールドは、ADD時に必須となり、SET時に省略可能となります。</div> <div lang=\"en\">Conversion tracker name.<br> This field is required in ADD operation, and is optional in SET operation.</div>   # noqa: E501

        :param conversion_tracker_name: The conversion_tracker_name of this ConversionTracker.  # noqa: E501
        :type: str
        """

        self._conversion_tracker_name = conversion_tracker_name

    @property
    def conversion_tracker_type(self):
        """Gets the conversion_tracker_type of this ConversionTracker.  # noqa: E501


        :return: The conversion_tracker_type of this ConversionTracker.  # noqa: E501
        :rtype: ConversionTrackerServiceConversionTrackerType
        """
        return self._conversion_tracker_type

    @conversion_tracker_type.setter
    def conversion_tracker_type(self, conversion_tracker_type):
        """Sets the conversion_tracker_type of this ConversionTracker.


        :param conversion_tracker_type: The conversion_tracker_type of this ConversionTracker.  # noqa: E501
        :type: ConversionTrackerServiceConversionTrackerType
        """

        self._conversion_tracker_type = conversion_tracker_type

    @property
    def conversion_value(self):
        """Gets the conversion_value of this ConversionTracker.  # noqa: E501

        <div lang=\"ja\"> 自動入札設定対象のコンバージョン値です。<br> この値はGETでのみ取得可能です。ADD、SET時のレスポンスではnullで返却されます。 </div> <div lang=\"en\"> Conversion value to be included to auto bidding.<br> This value can be obtained by GET operation only. ADD and SET responses will return null. </div>   # noqa: E501

        :return: The conversion_value of this ConversionTracker.  # noqa: E501
        :rtype: str
        """
        return self._conversion_value

    @conversion_value.setter
    def conversion_value(self, conversion_value):
        """Sets the conversion_value of this ConversionTracker.

        <div lang=\"ja\"> 自動入札設定対象のコンバージョン値です。<br> この値はGETでのみ取得可能です。ADD、SET時のレスポンスではnullで返却されます。 </div> <div lang=\"en\"> Conversion value to be included to auto bidding.<br> This value can be obtained by GET operation only. ADD and SET responses will return null. </div>   # noqa: E501

        :param conversion_value: The conversion_value of this ConversionTracker.  # noqa: E501
        :type: str
        """

        self._conversion_value = conversion_value

    @property
    def conversions(self):
        """Gets the conversions of this ConversionTracker.  # noqa: E501

        <div lang=\"ja\"> 自動入札設定対象のコンバージョン数です。<br> ユニークコンバージョンか総コンバージョンかは、countingTypeに依存します。<br> この値はGETでのみ取得可能です。ADD、SET時のレスポンスではnullで返却されます。 </div> <div lang=\"en\"> Conversions which counts as included to auto bidding setting.<br> countingType specifies whether one-per-click or many-per-click.<br> This value can be obtained by GET operation only. ADD and SET responses will return null. </div>   # noqa: E501

        :return: The conversions of this ConversionTracker.  # noqa: E501
        :rtype: int
        """
        return self._conversions

    @conversions.setter
    def conversions(self, conversions):
        """Sets the conversions of this ConversionTracker.

        <div lang=\"ja\"> 自動入札設定対象のコンバージョン数です。<br> ユニークコンバージョンか総コンバージョンかは、countingTypeに依存します。<br> この値はGETでのみ取得可能です。ADD、SET時のレスポンスではnullで返却されます。 </div> <div lang=\"en\"> Conversions which counts as included to auto bidding setting.<br> countingType specifies whether one-per-click or many-per-click.<br> This value can be obtained by GET operation only. ADD and SET responses will return null. </div>   # noqa: E501

        :param conversions: The conversions of this ConversionTracker.  # noqa: E501
        :type: int
        """

        self._conversions = conversions

    @property
    def exclude_from_bidding(self):
        """Gets the exclude_from_bidding of this ConversionTracker.  # noqa: E501


        :return: The exclude_from_bidding of this ConversionTracker.  # noqa: E501
        :rtype: ConversionTrackerServiceExcludeFromBidding
        """
        return self._exclude_from_bidding

    @exclude_from_bidding.setter
    def exclude_from_bidding(self, exclude_from_bidding):
        """Sets the exclude_from_bidding of this ConversionTracker.


        :param exclude_from_bidding: The exclude_from_bidding of this ConversionTracker.  # noqa: E501
        :type: ConversionTrackerServiceExcludeFromBidding
        """

        self._exclude_from_bidding = exclude_from_bidding

    @property
    def measurement_period(self):
        """Gets the measurement_period of this ConversionTracker.  # noqa: E501

        <div lang=\"ja\">コンバージョン計測期間です（単位：日)。<br> 7～90日間で設定可能です。<br>※アプリダウンロードの場合は30日間固定。<br> このフィールドは、ADDおよびSET時に省略可能となります。<br>※ADD時のデフォルト設定値は30となります。<br> ※conversionTrackerTypeがAPP_LINK_CONVERSIONの場合、ADDおよびSET時にappEventTypeがfirst_openの場合は30のみ指定可能となります。<br> appEventTypeはConversionTrackerService/getAppEventTypeで取得されるappEvent.appEventTypeで確認できます。</div> <div lang=\"en\">Counting period of conversions (days).<br>It is available between 7 to 90 days<br> * For Mobile App Download, this period is fixed as 30 days.<br> This field is optional in ADD and SET operation.<br> * The default value in ADD operation will be 30.<br> * In ADD and SET operation, if conversionTrackerType is APP_LINK_CONVERSION and appEventType is first_open, Only 30 can be specified.<br> appEventType can be confirmed by appEvent.appEventType obtained by ConversionTrackerService/getAppEventType.</div>   # noqa: E501

        :return: The measurement_period of this ConversionTracker.  # noqa: E501
        :rtype: int
        """
        return self._measurement_period

    @measurement_period.setter
    def measurement_period(self, measurement_period):
        """Sets the measurement_period of this ConversionTracker.

        <div lang=\"ja\">コンバージョン計測期間です（単位：日)。<br> 7～90日間で設定可能です。<br>※アプリダウンロードの場合は30日間固定。<br> このフィールドは、ADDおよびSET時に省略可能となります。<br>※ADD時のデフォルト設定値は30となります。<br> ※conversionTrackerTypeがAPP_LINK_CONVERSIONの場合、ADDおよびSET時にappEventTypeがfirst_openの場合は30のみ指定可能となります。<br> appEventTypeはConversionTrackerService/getAppEventTypeで取得されるappEvent.appEventTypeで確認できます。</div> <div lang=\"en\">Counting period of conversions (days).<br>It is available between 7 to 90 days<br> * For Mobile App Download, this period is fixed as 30 days.<br> This field is optional in ADD and SET operation.<br> * The default value in ADD operation will be 30.<br> * In ADD and SET operation, if conversionTrackerType is APP_LINK_CONVERSION and appEventType is first_open, Only 30 can be specified.<br> appEventType can be confirmed by appEvent.appEventType obtained by ConversionTrackerService/getAppEventType.</div>   # noqa: E501

        :param measurement_period: The measurement_period of this ConversionTracker.  # noqa: E501
        :type: int
        """

        self._measurement_period = measurement_period

    @property
    def most_recent_conversion_date(self):
        """Gets the most_recent_conversion_date of this ConversionTracker.  # noqa: E501

        <div lang=\"ja\">直近のコンバージョン発生日です。</div> <div lang=\"en\">The most latest date when conversion occurred.</div>   # noqa: E501

        :return: The most_recent_conversion_date of this ConversionTracker.  # noqa: E501
        :rtype: str
        """
        return self._most_recent_conversion_date

    @most_recent_conversion_date.setter
    def most_recent_conversion_date(self, most_recent_conversion_date):
        """Sets the most_recent_conversion_date of this ConversionTracker.

        <div lang=\"ja\">直近のコンバージョン発生日です。</div> <div lang=\"en\">The most latest date when conversion occurred.</div>   # noqa: E501

        :param most_recent_conversion_date: The most_recent_conversion_date of this ConversionTracker.  # noqa: E501
        :type: str
        """

        self._most_recent_conversion_date = most_recent_conversion_date

    @property
    def status(self):
        """Gets the status of this ConversionTracker.  # noqa: E501


        :return: The status of this ConversionTracker.  # noqa: E501
        :rtype: ConversionTrackerServiceStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ConversionTracker.


        :param status: The status of this ConversionTracker.  # noqa: E501
        :type: ConversionTrackerServiceStatus
        """

        self._status = status

    @property
    def user_revenue_value(self):
        """Gets the user_revenue_value of this ConversionTracker.  # noqa: E501

        <div lang=\"ja\">このコンバージョントラッカーに対するユーザー指定の収益値です。<br> 1コンバージョンあたりの売上金額が固定値の場合、その金額を設定することで、売上金額をレポートなどで確認できます。<br> ADDリクエスト時に未指定の場合、0が設定されます。<br> このフィールドは、ADD時およびSET時に省略可能となります。<br> ※conversionTrackerTypeがAPP_LINK_CONVERSIONの場合、ADDおよびSET時にappEventTypeがin_app_purchaseの場合は0のみ指定可能となります。<br> appEventTypeはConversionTrackerService/getAppEventTypeで取得されるappEvent.appEventTypeで確認できます。</div> <div lang=\"en\">The value of revenue of the conversion tracker specified by user.<br> When the sales revenue of 1 conversion is fixed value, you are able to review the total sales on reports by specifying the amount on this item.<br> If it is not specified on ADD request, the value &#34;0&#34; is set.<br> This field is optional in ADD and SET operation.<br> * In ADD and SET operation, if conversionTrackerType is APP_LINK_CONVERSION and appEventType is in_app_purchase, Only 0 can be specified.<br> appEventType can be confirmed by appEvent.appEventType obtained by ConversionTrackerService/getAppEventType.</div>   # noqa: E501

        :return: The user_revenue_value of this ConversionTracker.  # noqa: E501
        :rtype: str
        """
        return self._user_revenue_value

    @user_revenue_value.setter
    def user_revenue_value(self, user_revenue_value):
        """Sets the user_revenue_value of this ConversionTracker.

        <div lang=\"ja\">このコンバージョントラッカーに対するユーザー指定の収益値です。<br> 1コンバージョンあたりの売上金額が固定値の場合、その金額を設定することで、売上金額をレポートなどで確認できます。<br> ADDリクエスト時に未指定の場合、0が設定されます。<br> このフィールドは、ADD時およびSET時に省略可能となります。<br> ※conversionTrackerTypeがAPP_LINK_CONVERSIONの場合、ADDおよびSET時にappEventTypeがin_app_purchaseの場合は0のみ指定可能となります。<br> appEventTypeはConversionTrackerService/getAppEventTypeで取得されるappEvent.appEventTypeで確認できます。</div> <div lang=\"en\">The value of revenue of the conversion tracker specified by user.<br> When the sales revenue of 1 conversion is fixed value, you are able to review the total sales on reports by specifying the amount on this item.<br> If it is not specified on ADD request, the value &#34;0&#34; is set.<br> This field is optional in ADD and SET operation.<br> * In ADD and SET operation, if conversionTrackerType is APP_LINK_CONVERSION and appEventType is in_app_purchase, Only 0 can be specified.<br> appEventType can be confirmed by appEvent.appEventType obtained by ConversionTrackerService/getAppEventType.</div>   # noqa: E501

        :param user_revenue_value: The user_revenue_value of this ConversionTracker.  # noqa: E501
        :type: str
        """

        self._user_revenue_value = user_revenue_value

    @property
    def web_conversion(self):
        """Gets the web_conversion of this ConversionTracker.  # noqa: E501


        :return: The web_conversion of this ConversionTracker.  # noqa: E501
        :rtype: ConversionTrackerServiceWebConversion
        """
        return self._web_conversion

    @web_conversion.setter
    def web_conversion(self, web_conversion):
        """Sets the web_conversion of this ConversionTracker.


        :param web_conversion: The web_conversion of this ConversionTracker.  # noqa: E501
        :type: ConversionTrackerServiceWebConversion
        """

        self._web_conversion = web_conversion

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConversionTracker):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ConversionTracker):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class AuditLogServiceValue(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'errors': 'list[Error]',
        'job': 'AuditLogServiceJob',
        'operation_succeeded': 'bool'
    }

    attribute_map = {
        'errors': 'errors',
        'job': 'job',
        'operation_succeeded': 'operationSucceeded'
    }

    def __init__(self, errors=None, job=None, operation_succeeded=None, local_vars_configuration=None):  # noqa: E501
        """AuditLogServiceValue - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._errors = None
        self._job = None
        self._operation_succeeded = None
        self.discriminator = None

        self.errors = errors
        self.job = job
        self.operation_succeeded = operation_succeeded

    @property
    def errors(self):
        """Gets the errors of this AuditLogServiceValue.  # noqa: E501


        :return: The errors of this AuditLogServiceValue.  # noqa: E501
        :rtype: list[Error]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this AuditLogServiceValue.


        :param errors: The errors of this AuditLogServiceValue.  # noqa: E501
        :type: list[Error]
        """

        self._errors = errors

    @property
    def job(self):
        """Gets the job of this AuditLogServiceValue.  # noqa: E501


        :return: The job of this AuditLogServiceValue.  # noqa: E501
        :rtype: AuditLogServiceJob
        """
        return self._job

    @job.setter
    def job(self, job):
        """Sets the job of this AuditLogServiceValue.


        :param job: The job of this AuditLogServiceValue.  # noqa: E501
        :type: AuditLogServiceJob
        """

        self._job = job

    @property
    def operation_succeeded(self):
        """Gets the operation_succeeded of this AuditLogServiceValue.  # noqa: E501

        <div lang=\"ja\">処理結果です。trueの場合は、処理は成功しました。falseの場合は処理が失敗しています。</div> <div lang=\"en\">The process results. If true, the process succeeded. If false, the process failed.</div>   # noqa: E501

        :return: The operation_succeeded of this AuditLogServiceValue.  # noqa: E501
        :rtype: bool
        """
        return self._operation_succeeded

    @operation_succeeded.setter
    def operation_succeeded(self, operation_succeeded):
        """Sets the operation_succeeded of this AuditLogServiceValue.

        <div lang=\"ja\">処理結果です。trueの場合は、処理は成功しました。falseの場合は処理が失敗しています。</div> <div lang=\"en\">The process results. If true, the process succeeded. If false, the process failed.</div>   # noqa: E501

        :param operation_succeeded: The operation_succeeded of this AuditLogServiceValue.  # noqa: E501
        :type: bool
        """

        self._operation_succeeded = operation_succeeded

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuditLogServiceValue):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AuditLogServiceValue):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class Campaign(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'int',
        'app_id': 'str',
        'app_os_type': 'CampaignServiceAppOsType',
        'bidding_strategy_configuration': 'CampaignServiceBiddingStrategy',
        'bidding_strategy_failed_reason': 'CampaignServiceBiddingStrategyFailedReason',
        'budget': 'CampaignServiceBudget',
        'campaign_id': 'int',
        'campaign_name': 'str',
        'campaign_track_id': 'int',
        'conversion_optimizer_eligibility': 'CampaignServiceConversionOptimizerEligibility',
        'custom_parameters': 'CampaignServiceCustomParameters',
        'end_date': 'str',
        'failed_bidding_strategy_configuration': 'CampaignServiceBiddingStrategy',
        'labels': 'list[CampaignServiceLabel]',
        'serving_status': 'CampaignServiceServingStatus',
        'settings': 'list[CampaignServiceSettings]',
        'start_date': 'str',
        'tracking_url': 'str',
        'type': 'CampaignServiceType',
        'url_review_data': 'CampaignServiceUrlReviewData',
        'user_status': 'CampaignServiceUserStatus',
        'created_date': 'str'
    }

    attribute_map = {
        'account_id': 'accountId',
        'app_id': 'appId',
        'app_os_type': 'appOsType',
        'bidding_strategy_configuration': 'biddingStrategyConfiguration',
        'bidding_strategy_failed_reason': 'biddingStrategyFailedReason',
        'budget': 'budget',
        'campaign_id': 'campaignId',
        'campaign_name': 'campaignName',
        'campaign_track_id': 'campaignTrackId',
        'conversion_optimizer_eligibility': 'conversionOptimizerEligibility',
        'custom_parameters': 'customParameters',
        'end_date': 'endDate',
        'failed_bidding_strategy_configuration': 'failedBiddingStrategyConfiguration',
        'labels': 'labels',
        'serving_status': 'servingStatus',
        'settings': 'settings',
        'start_date': 'startDate',
        'tracking_url': 'trackingUrl',
        'type': 'type',
        'url_review_data': 'urlReviewData',
        'user_status': 'userStatus',
        'created_date': 'createdDate'
    }

    def __init__(self, account_id=None, app_id=None, app_os_type=None, bidding_strategy_configuration=None, bidding_strategy_failed_reason=None, budget=None, campaign_id=None, campaign_name=None, campaign_track_id=None, conversion_optimizer_eligibility=None, custom_parameters=None, end_date=None, failed_bidding_strategy_configuration=None, labels=None, serving_status=None, settings=None, start_date=None, tracking_url=None, type=None, url_review_data=None, user_status=None, created_date=None, local_vars_configuration=None):  # noqa: E501
        """Campaign - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._app_id = None
        self._app_os_type = None
        self._bidding_strategy_configuration = None
        self._bidding_strategy_failed_reason = None
        self._budget = None
        self._campaign_id = None
        self._campaign_name = None
        self._campaign_track_id = None
        self._conversion_optimizer_eligibility = None
        self._custom_parameters = None
        self._end_date = None
        self._failed_bidding_strategy_configuration = None
        self._labels = None
        self._serving_status = None
        self._settings = None
        self._start_date = None
        self._tracking_url = None
        self._type = None
        self._url_review_data = None
        self._user_status = None
        self._created_date = None
        self.discriminator = None

        self.account_id = account_id
        self.app_id = app_id
        self.app_os_type = app_os_type
        self.bidding_strategy_configuration = bidding_strategy_configuration
        self.bidding_strategy_failed_reason = bidding_strategy_failed_reason
        self.budget = budget
        self.campaign_id = campaign_id
        self.campaign_name = campaign_name
        self.campaign_track_id = campaign_track_id
        self.conversion_optimizer_eligibility = conversion_optimizer_eligibility
        self.custom_parameters = custom_parameters
        self.end_date = end_date
        self.failed_bidding_strategy_configuration = failed_bidding_strategy_configuration
        self.labels = labels
        self.serving_status = serving_status
        self.settings = settings
        self.start_date = start_date
        self.tracking_url = tracking_url
        self.type = type
        self.url_review_data = url_review_data
        self.user_status = user_status
        self.created_date = created_date

    @property
    def account_id(self):
        """Gets the account_id of this Campaign.  # noqa: E501

        <div lang=\"ja\">アカウントIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Account ID.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The account_id of this Campaign.  # noqa: E501
        :rtype: int
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this Campaign.

        <div lang=\"ja\">アカウントIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Account ID.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param account_id: The account_id of this Campaign.  # noqa: E501
        :type: int
        """

        self._account_id = account_id

    @property
    def app_id(self):
        """Gets the app_id of this Campaign.  # noqa: E501

        <div lang=\"ja\">アプリID（iOS）またはパッケージ名（Android）です。<br> ※アプリキャンペーンでiOSの場合、入力は数値のみです。<br> ADD時、campaignTypeがSTANDARD、またはDYNAMIC_ADS_FOR_SEARCH_SETTINGの場合、無視され、MOBILE_APPの場合、必須となります。</div> <div lang=\"en\">App ID (for iOS) or Package name (for Android).<br> *Input only the numbers for iOS in Mobile App Campaign.<br>  In ADD operation, this field will be ignored when campaignType is 'STANDARD' or 'DYNAMIC_ADS_FOR_SEARCH_SETTING', and is required when campaignType is MOBILE_APP.</div>   # noqa: E501

        :return: The app_id of this Campaign.  # noqa: E501
        :rtype: str
        """
        return self._app_id

    @app_id.setter
    def app_id(self, app_id):
        """Sets the app_id of this Campaign.

        <div lang=\"ja\">アプリID（iOS）またはパッケージ名（Android）です。<br> ※アプリキャンペーンでiOSの場合、入力は数値のみです。<br> ADD時、campaignTypeがSTANDARD、またはDYNAMIC_ADS_FOR_SEARCH_SETTINGの場合、無視され、MOBILE_APPの場合、必須となります。</div> <div lang=\"en\">App ID (for iOS) or Package name (for Android).<br> *Input only the numbers for iOS in Mobile App Campaign.<br>  In ADD operation, this field will be ignored when campaignType is 'STANDARD' or 'DYNAMIC_ADS_FOR_SEARCH_SETTING', and is required when campaignType is MOBILE_APP.</div>   # noqa: E501

        :param app_id: The app_id of this Campaign.  # noqa: E501
        :type: str
        """

        self._app_id = app_id

    @property
    def app_os_type(self):
        """Gets the app_os_type of this Campaign.  # noqa: E501


        :return: The app_os_type of this Campaign.  # noqa: E501
        :rtype: CampaignServiceAppOsType
        """
        return self._app_os_type

    @app_os_type.setter
    def app_os_type(self, app_os_type):
        """Sets the app_os_type of this Campaign.


        :param app_os_type: The app_os_type of this Campaign.  # noqa: E501
        :type: CampaignServiceAppOsType
        """

        self._app_os_type = app_os_type

    @property
    def bidding_strategy_configuration(self):
        """Gets the bidding_strategy_configuration of this Campaign.  # noqa: E501


        :return: The bidding_strategy_configuration of this Campaign.  # noqa: E501
        :rtype: CampaignServiceBiddingStrategy
        """
        return self._bidding_strategy_configuration

    @bidding_strategy_configuration.setter
    def bidding_strategy_configuration(self, bidding_strategy_configuration):
        """Sets the bidding_strategy_configuration of this Campaign.


        :param bidding_strategy_configuration: The bidding_strategy_configuration of this Campaign.  # noqa: E501
        :type: CampaignServiceBiddingStrategy
        """

        self._bidding_strategy_configuration = bidding_strategy_configuration

    @property
    def bidding_strategy_failed_reason(self):
        """Gets the bidding_strategy_failed_reason of this Campaign.  # noqa: E501


        :return: The bidding_strategy_failed_reason of this Campaign.  # noqa: E501
        :rtype: CampaignServiceBiddingStrategyFailedReason
        """
        return self._bidding_strategy_failed_reason

    @bidding_strategy_failed_reason.setter
    def bidding_strategy_failed_reason(self, bidding_strategy_failed_reason):
        """Sets the bidding_strategy_failed_reason of this Campaign.


        :param bidding_strategy_failed_reason: The bidding_strategy_failed_reason of this Campaign.  # noqa: E501
        :type: CampaignServiceBiddingStrategyFailedReason
        """

        self._bidding_strategy_failed_reason = bidding_strategy_failed_reason

    @property
    def budget(self):
        """Gets the budget of this Campaign.  # noqa: E501


        :return: The budget of this Campaign.  # noqa: E501
        :rtype: CampaignServiceBudget
        """
        return self._budget

    @budget.setter
    def budget(self, budget):
        """Sets the budget of this Campaign.


        :param budget: The budget of this Campaign.  # noqa: E501
        :type: CampaignServiceBudget
        """

        self._budget = budget

    @property
    def campaign_id(self):
        """Gets the campaign_id of this Campaign.  # noqa: E501

        <div lang=\"ja\">キャンペーンIDです。<br> SET時およびREMOVE時、このフィールドは必須です。</div> <div lang=\"en\">Campaign ID.<br> This field is required in SET and REMOVE operation.</div>   # noqa: E501

        :return: The campaign_id of this Campaign.  # noqa: E501
        :rtype: int
        """
        return self._campaign_id

    @campaign_id.setter
    def campaign_id(self, campaign_id):
        """Sets the campaign_id of this Campaign.

        <div lang=\"ja\">キャンペーンIDです。<br> SET時およびREMOVE時、このフィールドは必須です。</div> <div lang=\"en\">Campaign ID.<br> This field is required in SET and REMOVE operation.</div>   # noqa: E501

        :param campaign_id: The campaign_id of this Campaign.  # noqa: E501
        :type: int
        """

        self._campaign_id = campaign_id

    @property
    def campaign_name(self):
        """Gets the campaign_name of this Campaign.  # noqa: E501

        <div lang=\"ja\">キャンペーン名です。<br>このフィールドは、ADD時に必須となり、SET時に省略可能となります。<br> ※入力制限：50文字以内です。</div> <div lang=\"en\">Campaign name.<br> *Insert limit: Up to 50 characters.<br>This field is required in ADD operation, and will be optional in SET operation.</div>   # noqa: E501

        :return: The campaign_name of this Campaign.  # noqa: E501
        :rtype: str
        """
        return self._campaign_name

    @campaign_name.setter
    def campaign_name(self, campaign_name):
        """Sets the campaign_name of this Campaign.

        <div lang=\"ja\">キャンペーン名です。<br>このフィールドは、ADD時に必須となり、SET時に省略可能となります。<br> ※入力制限：50文字以内です。</div> <div lang=\"en\">Campaign name.<br> *Insert limit: Up to 50 characters.<br>This field is required in ADD operation, and will be optional in SET operation.</div>   # noqa: E501

        :param campaign_name: The campaign_name of this Campaign.  # noqa: E501
        :type: str
        """

        self._campaign_name = campaign_name

    @property
    def campaign_track_id(self):
        """Gets the campaign_track_id of this Campaign.  # noqa: E501

        <div lang=\"ja\">トラッキング用キャンペーンIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Campaign ID for tracking.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :return: The campaign_track_id of this Campaign.  # noqa: E501
        :rtype: int
        """
        return self._campaign_track_id

    @campaign_track_id.setter
    def campaign_track_id(self, campaign_track_id):
        """Sets the campaign_track_id of this Campaign.

        <div lang=\"ja\">トラッキング用キャンペーンIDです。<br> このフィールドは、レスポンスの際に返却されますが、リクエストの際には無視されます。</div> <div lang=\"en\">Campaign ID for tracking.<br> Although this field will be returned in the response, it will be ignored on input.</div>   # noqa: E501

        :param campaign_track_id: The campaign_track_id of this Campaign.  # noqa: E501
        :type: int
        """

        self._campaign_track_id = campaign_track_id

    @property
    def conversion_optimizer_eligibility(self):
        """Gets the conversion_optimizer_eligibility of this Campaign.  # noqa: E501


        :return: The conversion_optimizer_eligibility of this Campaign.  # noqa: E501
        :rtype: CampaignServiceConversionOptimizerEligibility
        """
        return self._conversion_optimizer_eligibility

    @conversion_optimizer_eligibility.setter
    def conversion_optimizer_eligibility(self, conversion_optimizer_eligibility):
        """Sets the conversion_optimizer_eligibility of this Campaign.


        :param conversion_optimizer_eligibility: The conversion_optimizer_eligibility of this Campaign.  # noqa: E501
        :type: CampaignServiceConversionOptimizerEligibility
        """

        self._conversion_optimizer_eligibility = conversion_optimizer_eligibility

    @property
    def custom_parameters(self):
        """Gets the custom_parameters of this Campaign.  # noqa: E501


        :return: The custom_parameters of this Campaign.  # noqa: E501
        :rtype: CampaignServiceCustomParameters
        """
        return self._custom_parameters

    @custom_parameters.setter
    def custom_parameters(self, custom_parameters):
        """Sets the custom_parameters of this Campaign.


        :param custom_parameters: The custom_parameters of this Campaign.  # noqa: E501
        :type: CampaignServiceCustomParameters
        """

        self._custom_parameters = custom_parameters

    @property
    def end_date(self):
        """Gets the end_date of this Campaign.  # noqa: E501

        <div lang=\"ja\">キャンペーンの終了日です。<br> ADD時およびSET時、このフィールドは省略可能となります。ADD時のデフォルト設定値は20371231となります。<br> 過去の日付、開始日以前の日付は指定できません。<br>※YYYYMMDD形式です。</div> <div lang=\"en\">End date of Campaign.<br> This field is optional in ADD and SET operation. The default value in ADD operation will be 20371231.<br> *Cannot set the past date and date before the start date.<br> *In YYYYMMDD format.</div>   # noqa: E501

        :return: The end_date of this Campaign.  # noqa: E501
        :rtype: str
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this Campaign.

        <div lang=\"ja\">キャンペーンの終了日です。<br> ADD時およびSET時、このフィールドは省略可能となります。ADD時のデフォルト設定値は20371231となります。<br> 過去の日付、開始日以前の日付は指定できません。<br>※YYYYMMDD形式です。</div> <div lang=\"en\">End date of Campaign.<br> This field is optional in ADD and SET operation. The default value in ADD operation will be 20371231.<br> *Cannot set the past date and date before the start date.<br> *In YYYYMMDD format.</div>   # noqa: E501

        :param end_date: The end_date of this Campaign.  # noqa: E501
        :type: str
        """

        self._end_date = end_date

    @property
    def failed_bidding_strategy_configuration(self):
        """Gets the failed_bidding_strategy_configuration of this Campaign.  # noqa: E501


        :return: The failed_bidding_strategy_configuration of this Campaign.  # noqa: E501
        :rtype: CampaignServiceBiddingStrategy
        """
        return self._failed_bidding_strategy_configuration

    @failed_bidding_strategy_configuration.setter
    def failed_bidding_strategy_configuration(self, failed_bidding_strategy_configuration):
        """Sets the failed_bidding_strategy_configuration of this Campaign.


        :param failed_bidding_strategy_configuration: The failed_bidding_strategy_configuration of this Campaign.  # noqa: E501
        :type: CampaignServiceBiddingStrategy
        """

        self._failed_bidding_strategy_configuration = failed_bidding_strategy_configuration

    @property
    def labels(self):
        """Gets the labels of this Campaign.  # noqa: E501


        :return: The labels of this Campaign.  # noqa: E501
        :rtype: list[CampaignServiceLabel]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this Campaign.


        :param labels: The labels of this Campaign.  # noqa: E501
        :type: list[CampaignServiceLabel]
        """

        self._labels = labels

    @property
    def serving_status(self):
        """Gets the serving_status of this Campaign.  # noqa: E501


        :return: The serving_status of this Campaign.  # noqa: E501
        :rtype: CampaignServiceServingStatus
        """
        return self._serving_status

    @serving_status.setter
    def serving_status(self, serving_status):
        """Sets the serving_status of this Campaign.


        :param serving_status: The serving_status of this Campaign.  # noqa: E501
        :type: CampaignServiceServingStatus
        """

        self._serving_status = serving_status

    @property
    def settings(self):
        """Gets the settings of this Campaign.  # noqa: E501


        :return: The settings of this Campaign.  # noqa: E501
        :rtype: list[CampaignServiceSettings]
        """
        return self._settings

    @settings.setter
    def settings(self, settings):
        """Sets the settings of this Campaign.


        :param settings: The settings of this Campaign.  # noqa: E501
        :type: list[CampaignServiceSettings]
        """

        self._settings = settings

    @property
    def start_date(self):
        """Gets the start_date of this Campaign.  # noqa: E501

        <div lang=\"ja\">キャンペーンの開始日です。<br> ADD時およびSET時、このフィールドは省略可能となります。ADD時のデフォルト設定値は当日日付となります。<br> 過去の日付は指定できません。<br>※配信開始済みのキャンペーンは変更できません。<br> ※YYYYMMDD形式です。</div> <div lang=\"en\">Start date of Campaign.<br> This field is optional in ADD and SET operation. The default value in ADD operation will be Today's date.<br> *Cannot set the past date.<br>*Cannot change the date to the campaign that is already active.<br> *In YYYYMMDD format.</div>   # noqa: E501

        :return: The start_date of this Campaign.  # noqa: E501
        :rtype: str
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this Campaign.

        <div lang=\"ja\">キャンペーンの開始日です。<br> ADD時およびSET時、このフィールドは省略可能となります。ADD時のデフォルト設定値は当日日付となります。<br> 過去の日付は指定できません。<br>※配信開始済みのキャンペーンは変更できません。<br> ※YYYYMMDD形式です。</div> <div lang=\"en\">Start date of Campaign.<br> This field is optional in ADD and SET operation. The default value in ADD operation will be Today's date.<br> *Cannot set the past date.<br>*Cannot change the date to the campaign that is already active.<br> *In YYYYMMDD format.</div>   # noqa: E501

        :param start_date: The start_date of this Campaign.  # noqa: E501
        :type: str
        """

        self._start_date = start_date

    @property
    def tracking_url(self):
        """Gets the tracking_url of this Campaign.  # noqa: E501

        <div lang=\"ja\">トラッキングURLです。<br> ADD時およびSET時、このフィールドは省略可能となります。<br> ※アプリキャンペーンがAndroidの場合、設定はできません。</div> <div lang=\"en\">Tracking URL.<br> This field is optional in ADD and SET operation.<br> *Cannot set if Mobile App Campaign is in Android.</div>   # noqa: E501

        :return: The tracking_url of this Campaign.  # noqa: E501
        :rtype: str
        """
        return self._tracking_url

    @tracking_url.setter
    def tracking_url(self, tracking_url):
        """Sets the tracking_url of this Campaign.

        <div lang=\"ja\">トラッキングURLです。<br> ADD時およびSET時、このフィールドは省略可能となります。<br> ※アプリキャンペーンがAndroidの場合、設定はできません。</div> <div lang=\"en\">Tracking URL.<br> This field is optional in ADD and SET operation.<br> *Cannot set if Mobile App Campaign is in Android.</div>   # noqa: E501

        :param tracking_url: The tracking_url of this Campaign.  # noqa: E501
        :type: str
        """

        self._tracking_url = tracking_url

    @property
    def type(self):
        """Gets the type of this Campaign.  # noqa: E501


        :return: The type of this Campaign.  # noqa: E501
        :rtype: CampaignServiceType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Campaign.


        :param type: The type of this Campaign.  # noqa: E501
        :type: CampaignServiceType
        """

        self._type = type

    @property
    def url_review_data(self):
        """Gets the url_review_data of this Campaign.  # noqa: E501


        :return: The url_review_data of this Campaign.  # noqa: E501
        :rtype: CampaignServiceUrlReviewData
        """
        return self._url_review_data

    @url_review_data.setter
    def url_review_data(self, url_review_data):
        """Sets the url_review_data of this Campaign.


        :param url_review_data: The url_review_data of this Campaign.  # noqa: E501
        :type: CampaignServiceUrlReviewData
        """

        self._url_review_data = url_review_data

    @property
    def user_status(self):
        """Gets the user_status of this Campaign.  # noqa: E501


        :return: The user_status of this Campaign.  # noqa: E501
        :rtype: CampaignServiceUserStatus
        """
        return self._user_status

    @user_status.setter
    def user_status(self, user_status):
        """Sets the user_status of this Campaign.


        :param user_status: The user_status of this Campaign.  # noqa: E501
        :type: CampaignServiceUserStatus
        """

        self._user_status = user_status

    @property
    def created_date(self):
        """Gets the created_date of this Campaign.  # noqa: E501

        <div lang=\"ja\">キャンペーンが作成された日です。<br>※フォーマット：yyyyMMdd</div> <div lang=\"en\">Date of Campaign made.<br>* Format: yyyyMMdd</div>   # noqa: E501

        :return: The created_date of this Campaign.  # noqa: E501
        :rtype: str
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this Campaign.

        <div lang=\"ja\">キャンペーンが作成された日です。<br>※フォーマット：yyyyMMdd</div> <div lang=\"en\">Date of Campaign made.<br>* Format: yyyyMMdd</div>   # noqa: E501

        :param created_date: The created_date of this Campaign.  # noqa: E501
        :type: str
        """

        self._created_date = created_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Campaign):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Campaign):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Yahoo!広告 検索広告 API リファレンス / Yahoo! JAPAN Ads Search Ads API Reference

    <div lang=\"ja\">Yahoo!広告 検索広告 APIのWebサービスについて説明します。</div> <div lang=\"en\">Search Ads API Web Services supported in Yahoo! JAPAN Ads API.</div> <div><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/design/v12/Route.yaml\">OpenAPI Specification</a></div> <div lang=\"ja\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/ja\">Best Practice</a></div> <div lang=\"en\"><a target=\"_blank\" href=\"https://github.com/yahoojp-marketing/ads-search-api-documents/blob/master/bestpractice/en\">Best Practice</a></div>   # noqa: E501

    The version of the OpenAPI document: v12
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from yahoo_search_api_v12.configuration import Configuration


class AdGroupAdServiceExtendedTextAd(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'headline': 'str',
        'headline2': 'str',
        'headline3': 'str',
        'description': 'str',
        'description2': 'str',
        'path1': 'str',
        'path2': 'str'
    }

    attribute_map = {
        'headline': 'headline',
        'headline2': 'headline2',
        'headline3': 'headline3',
        'description': 'description',
        'description2': 'description2',
        'path1': 'path1',
        'path2': 'path2'
    }

    def __init__(self, headline=None, headline2=None, headline3=None, description=None, description2=None, path1=None, path2=None, local_vars_configuration=None):  # noqa: E501
        """AdGroupAdServiceExtendedTextAd - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._headline = None
        self._headline2 = None
        self._headline3 = None
        self._description = None
        self._description2 = None
        self._path1 = None
        self._path2 = None
        self.discriminator = None

        self.headline = headline
        self.headline2 = headline2
        self.headline3 = headline3
        self.description = description
        self.description2 = description2
        self.path1 = path1
        self.path2 = path2

    @property
    def headline(self):
        """Gets the headline of this AdGroupAdServiceExtendedTextAd.  # noqa: E501

        <div lang=\"ja\">タイトル文です。<br> ADD時、このフィールドは必須となります。</div> <div lang=\"en\">Title of ad.<br> This field is required in ADD operation. *If adType is DYNAMIC_SEARCH_LINKED_AD or RESPONSIVE_SEARCH_AD, this field will be ignored.</div>   # noqa: E501

        :return: The headline of this AdGroupAdServiceExtendedTextAd.  # noqa: E501
        :rtype: str
        """
        return self._headline

    @headline.setter
    def headline(self, headline):
        """Sets the headline of this AdGroupAdServiceExtendedTextAd.

        <div lang=\"ja\">タイトル文です。<br> ADD時、このフィールドは必須となります。</div> <div lang=\"en\">Title of ad.<br> This field is required in ADD operation. *If adType is DYNAMIC_SEARCH_LINKED_AD or RESPONSIVE_SEARCH_AD, this field will be ignored.</div>   # noqa: E501

        :param headline: The headline of this AdGroupAdServiceExtendedTextAd.  # noqa: E501
        :type: str
        """

        self._headline = headline

    @property
    def headline2(self):
        """Gets the headline2 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501

        <div lang=\"ja\">2行目のタイトルです。<br> ADD時、このフィールドは必須となります。</div> <div lang=\"en\">Title on the second line.<br> This field is required in ADD operation.</div>   # noqa: E501

        :return: The headline2 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501
        :rtype: str
        """
        return self._headline2

    @headline2.setter
    def headline2(self, headline2):
        """Sets the headline2 of this AdGroupAdServiceExtendedTextAd.

        <div lang=\"ja\">2行目のタイトルです。<br> ADD時、このフィールドは必須となります。</div> <div lang=\"en\">Title on the second line.<br> This field is required in ADD operation.</div>   # noqa: E501

        :param headline2: The headline2 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501
        :type: str
        """

        self._headline2 = headline2

    @property
    def headline3(self):
        """Gets the headline3 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501

        <div lang=\"ja\">3行目のタイトルです。<br> ADD時、このフィールドは省略可能となります。その際、デフォルト設定値はnullとなります。</div> <div lang=\"en\">Title on the second line.<br> This field is optional in ADD operation. The default value will be null.</div>   # noqa: E501

        :return: The headline3 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501
        :rtype: str
        """
        return self._headline3

    @headline3.setter
    def headline3(self, headline3):
        """Sets the headline3 of this AdGroupAdServiceExtendedTextAd.

        <div lang=\"ja\">3行目のタイトルです。<br> ADD時、このフィールドは省略可能となります。その際、デフォルト設定値はnullとなります。</div> <div lang=\"en\">Title on the second line.<br> This field is optional in ADD operation. The default value will be null.</div>   # noqa: E501

        :param headline3: The headline3 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501
        :type: str
        """

        self._headline3 = headline3

    @property
    def description(self):
        """Gets the description of this AdGroupAdServiceExtendedTextAd.  # noqa: E501

        <div lang=\"ja\">説明文です。<br> ADD時、このフィールドは必須となります。<br>自動挿入をサポートしていません。</div> <div lang=\"en\">Description of ad.<br> This field is required in ADD operation. *If adType is RESPONSIVE_SEARCH_AD, this field will be ignored.<br>Does not support Data Auto Insertion.</div>   # noqa: E501

        :return: The description of this AdGroupAdServiceExtendedTextAd.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AdGroupAdServiceExtendedTextAd.

        <div lang=\"ja\">説明文です。<br> ADD時、このフィールドは必須となります。<br>自動挿入をサポートしていません。</div> <div lang=\"en\">Description of ad.<br> This field is required in ADD operation. *If adType is RESPONSIVE_SEARCH_AD, this field will be ignored.<br>Does not support Data Auto Insertion.</div>   # noqa: E501

        :param description: The description of this AdGroupAdServiceExtendedTextAd.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def description2(self):
        """Gets the description2 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501

        <div lang=\"ja\">2行目の説明文です。<br> ADD時、このフィールドは省略可能となります。その際、デフォルト設定値はnullとなります。</div> <div lang=\"en\">Description on the second line.<br> This field is optional in ADD operation. The default value will be null.</div>   # noqa: E501

        :return: The description2 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501
        :rtype: str
        """
        return self._description2

    @description2.setter
    def description2(self, description2):
        """Sets the description2 of this AdGroupAdServiceExtendedTextAd.

        <div lang=\"ja\">2行目の説明文です。<br> ADD時、このフィールドは省略可能となります。その際、デフォルト設定値はnullとなります。</div> <div lang=\"en\">Description on the second line.<br> This field is optional in ADD operation. The default value will be null.</div>   # noqa: E501

        :param description2: The description2 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501
        :type: str
        """

        self._description2 = description2

    @property
    def path1(self):
        """Gets the path1 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501

        <div lang=\"ja\">自動作成される表示URLを補足するパスです。<br> ADD時、このフィールドは省略可能となります。その際、デフォルト設定値はnullとなります。<br>※path2を指定する場合は、path1は必須です。</div> <div lang=\"en\">The path information which complements display URL generated automatically.<br> This field is optional in ADD operation. The default value will be null.<br>*To specify path2, path1 is required.</div>   # noqa: E501

        :return: The path1 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501
        :rtype: str
        """
        return self._path1

    @path1.setter
    def path1(self, path1):
        """Sets the path1 of this AdGroupAdServiceExtendedTextAd.

        <div lang=\"ja\">自動作成される表示URLを補足するパスです。<br> ADD時、このフィールドは省略可能となります。その際、デフォルト設定値はnullとなります。<br>※path2を指定する場合は、path1は必須です。</div> <div lang=\"en\">The path information which complements display URL generated automatically.<br> This field is optional in ADD operation. The default value will be null.<br>*To specify path2, path1 is required.</div>   # noqa: E501

        :param path1: The path1 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501
        :type: str
        """

        self._path1 = path1

    @property
    def path2(self):
        """Gets the path2 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501

        <div lang=\"ja\">自動作成される表示URLを補足するパスです。<br> ADD時、このフィールドは省略可能となります。その際、デフォルト設定値はnullとなります。<br>※path1を指定していない場合、path2は無視されます。</div> <div lang=\"en\">The path information which complements display URL generated automatically.<br> This field is optional in ADD operation. The default value will be null.<br>*If path1 is not specified, path2 will be ignored.</div>   # noqa: E501

        :return: The path2 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501
        :rtype: str
        """
        return self._path2

    @path2.setter
    def path2(self, path2):
        """Sets the path2 of this AdGroupAdServiceExtendedTextAd.

        <div lang=\"ja\">自動作成される表示URLを補足するパスです。<br> ADD時、このフィールドは省略可能となります。その際、デフォルト設定値はnullとなります。<br>※path1を指定していない場合、path2は無視されます。</div> <div lang=\"en\">The path information which complements display URL generated automatically.<br> This field is optional in ADD operation. The default value will be null.<br>*If path1 is not specified, path2 will be ignored.</div>   # noqa: E501

        :param path2: The path2 of this AdGroupAdServiceExtendedTextAd.  # noqa: E501
        :type: str
        """

        self._path2 = path2

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdGroupAdServiceExtendedTextAd):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AdGroupAdServiceExtendedTextAd):
            return True

        return self.to_dict() != other.to_dict()
